/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geviewer.render;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Geometry;
import java.awt.Graphics2D;
import java.awt.Polygon;
import java.awt.Rectangle;
import java.awt.geom.Point2D;

/**
 * Generic Geometry Renderer
 *
 * @author Timon Veenstra
 */
public class GeometryRenderer<G extends Geometry> {

    /**
     * 
     * @param geometry The geometry to calculate a viewport for
     * @param boundingBox collection.getEnvelope(); in case of a geometry collection
     * @param canvas  mapViewer.getViewportBounds() in case of mapviewer
     * @param translator The translator to translate pixels to geo and visa versa
     * @param g 
     */
    public void render(G geometry, Geometry boundingBox, Rectangle canvas, GeoTranslator translator, Graphics2D g) {
        //
        // draw the geometry
        //
        Polygon polygon = new Polygon();
        if (geometry.getCoordinates().length > 1) {
            for (Coordinate coordinate : geometry.getCoordinates()) {
                Point2D point2D = translator.geoToPixel(canvas, boundingBox, coordinate);

                int x = (int) (point2D.getX() - canvas.getBounds().getX());
                int y = (int) (point2D.getY() - canvas.getBounds().getY());

                polygon.addPoint(x, y);
            }
            g.clip(polygon);
            g.fill(polygon);
        }
    }


    /**
     * Calculate viewport from specified mapviewer and geometry
     *
     * @param geometry The geometry to calculate a viewport for
     * @param boundingbox collection.getEnvelope(); in case of a geometry collection
     * if viewport for single viewport is required pas in bounds of geometry
     * @param canvas mapViewer.getViewportBounds() in case of mapviewer
     * @param translator The translator to translate pixels to geo and visa versa
     * @return
     */
    public static Rectangle getViewport(Geometry geometry, Geometry boundingbox, Rectangle canvas, GeoTranslator translator) {
        //
        // determine the box the geometry will be drawn in
        //
        Rectangle bounds = new Rectangle(0, 0, -1, -1);

        for (Coordinate boundryCoord : geometry.getBoundary().getCoordinates()) {
            Point2D point2D = translator.geoToPixel(canvas, boundingbox, boundryCoord);

            int x = (int) (point2D.getX() - canvas.getBounds().getX());
            int y = (int) (point2D.getY() - canvas.getBounds().getY());

            bounds.add(x, y);
        }
        return bounds;
    }
}
