/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geviewer.render;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.MultiLineString;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.geom.Line2D;
import java.awt.geom.Point2D;

/**
 * Line shape renderer
 *
 * @author Gerben Feenstra
 */
public class MultiLineStringRenderer extends GeometryRenderer<MultiLineString> {

    public MultiLineStringRenderer() {
    }

    @Override
    public void render(MultiLineString geometry, Geometry boundingBox, Rectangle canvas, GeoTranslator translator, Graphics2D g) {
        //
        // determine the box the geometry will be drawn in
        //
        Line2D toDraw = new Line2D.Double();
        Coordinate[] coords = geometry.getCoordinates();

        if (coords.length > 1) {
            Point2D point2DA = translator.geoToPixel(canvas, boundingBox, coords[0]);
            Point2D point2DB = translator.geoToPixel(canvas, boundingBox, coords[1]);

            int pointAX = (int) (point2DA.getX() - canvas.x);
            int pointAY = (int) (point2DA.getY() - canvas.y);
            int pointBX = (int) (point2DB.getX() - canvas.x);
            int pointBY = (int) (point2DB.getY() - canvas.y);

            toDraw.setLine(pointAX, pointAY, pointBX, pointBY);

        }
        g.draw(toDraw);
    }
}
